@@ -1,5 +1,7 @@
 """
-Main interface for ssm service client waiters.
+Type annotations for ssm service client waiters.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html)
 
 Usage::
 
@@ -25,7 +27,7 @@ __all__ = ("CommandExecutedWaiter",)
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Waiter.CommandExecuted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
     """
 
     def wait(
@@ -36,5 +38,6 @@ class CommandExecutedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [CommandExecuted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.CommandExecuted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecuted)
         """
